class RPCMethod:

    web3_clientVersion = "web3_clientVersion"

    eth_accounts = "eth_accounts"
    eth_blockNumber = "eth_blockNumber"
    eth_gasPrice = "eth_gasPrice"

    eth_getBalance = "eth_getBalance"
    eth_getStorageAt = "eth_getStorageAt"
    eth_getBlockByHash = "eth_getBlockByHash"
    eth_getBlockByNumber = "eth_getBlockByNumber"
    eth_getTransactionCount = "eth_getTransactionCount"
    eth_getTransactionReceipt = "eth_getTransactionReceipt"
    eth_getTransactionByHash = "eth_getTransactionByHash"

    eth_call = "eth_call"
    eth_sendRawTransaction = "eth_sendRawTransaction"

    eth_subscribe = "eth_subscribe"
    eth_unsubscribe = "eth_unsubscribe"
